import React, { useState } from 'react'

import TodoCard from './todoCard.js'

import styles from './todoBoard.module.css'

export default function TodoBoard(props) {
  const { columns, cards, userId, categories, onCardClick, namedGroups } = props
  const [selectedGroup, setSelectedGroup] = useState(null)

  const clickableTypes = Object.keys(columns).reduce((acc, key) => {
    const col = columns[key]
    if (col.clickable) {
      acc.push(key)
    }
    return acc
  }, [])

  const groups = cards.reduce((acc, card) => {
    if (!acc.includes(card.group) && card.group) {
      acc.push(card.group)
    }
    return acc
  }, [])

  const renderGrouper = () => {
    const sg = namedGroups[selectedGroup]
    return (
      <>
        <div className={styles.groupContainer}>
          {groups.map((group) => {
            const namedGroup = namedGroups[group]
            return (
              <div
                className={`${styles.group} ${group === selectedGroup &&
                  styles.selectedGroup}`}
                key={group}
                onClick={() => {
                  setSelectedGroup(group)
                }}
              >
                {namedGroup ? namedGroup.name : group}
              </div>
            )
          })}
          <div
            className={styles.group}
            onClick={() => {
              setSelectedGroup(null)
            }}
          >
            {'Összes'}
          </div>
        </div>
        {sg && sg.description ? (
          <div className={styles.groupDescription}>{sg.description}</div>
        ) : null}
      </>
    )
  }

  return (
    <div className={styles.tableContainer}>
      {renderGrouper()}
      <div className={styles.table}>
        {Object.keys(columns).map((key) => {
          const category = columns[key]
          return (
            <div className={styles.tableCol} key={key}>
              <div className={styles.categoryName}>{category.name}</div>
              {cards.map((card, i) => {
                if (card.state === key) {
                  if (selectedGroup && card.group !== selectedGroup) {
                    return null
                  }
                  return (
                    <TodoCard
                      key={i}
                      cardData={card}
                      userId={userId}
                      categories={categories}
                      onClick={onCardClick}
                      clickable={clickableTypes.includes(key)}
                    />
                  )
                } else {
                  return null
                }
              })}
            </div>
          )
        })}
      </div>
    </div>
  )
}
